================================================
Welcome to django-denorm-iplweb's documentation!
================================================

django-denorm-iplweb provides a declarative way of denormalizing_ models in Django_ based applications while
maintaining data consistency.

.. _denormalizing: http://en.wikipedia.org/wiki/Denormalization
.. _Django: http://www.djangoproject.com

Contents
========

.. toctree::
   :maxdepth: 2

   tutorial
   reference
   history
